﻿// For an introduction to the Blank template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232509
(function () {
    "use strict";

    WinJS.Binding.optimizeBindingReferences = true;

    var app = WinJS.Application;
    var activation = Windows.ApplicationModel.Activation;

    app.onactivated = function (args) {
        if (args.detail.kind === activation.ActivationKind.launch) {
            if (args.detail.previousExecutionState !== activation.ApplicationExecutionState.terminated) {
                // TODO: This application has been newly launched. Initialize
                // your application here.
            } else {
                // TODO: This application has been reactivated from suspension.
                // Restore application state here.
            }
            document.getElementById("WriteFileThroughFileIO").addEventListener("click", WriteFileThroughFileIO_Click, false);
            document.getElementById("WriteFileThroughStream").addEventListener("click", WriteFileThroughStream_Click, false);
            document.getElementById("ReadFileThroughFileIO").addEventListener("click", ReadFileThroughFileIO_Click, false);
            document.getElementById("ReadFileThroughStream").addEventListener("click", ReadFileThroughStream_Click, false);
            document.getElementById("DeleteFile").addEventListener("click", DeleteFile_Click, false);
            document.getElementById("CreateFolder").addEventListener("click", CreateFolder_Click, false);
            document.getElementById("DeleteFolder").addEventListener("click", DeleteFolder_Click, false);
            document.getElementById("UseFileOpenPicker").addEventListener("click", UseFileOpenPicker_Click, false);
            document.getElementById("UseFileSavePicker").addEventListener("click", UseFileSavePicker_Click, false);
            document.getElementById("UseFolderSavePicker").addEventListener("click", UseFolderSavePicker_Click, false);

            args.setPromise(WinJS.UI.processAll());
        }
    };

    app.oncheckpoint = function (args) {
        // TODO: This application is about to be suspended. Save any state
        // that needs to persist across suspensions here. You might use the
        // WinJS.Application.sessionState object, which is automatically
        // saved and restored across suspension. If you need to complete an
        // asynchronous operation before your application is suspended, call
        // args.setPromise().
    };

    function WriteFileThroughFileIO_Click(eventInfo) {
    	var st = Windows.Storage;
    	st.ApplicationData.current.localFolder.createFileAsync("file.txt", st.CreationCollisionOption.replaceExisting)
				.then(function(file){
					return st.FileIO.writeTextAsync(file, new Date().toString());
				});
    }

    function WriteFileThroughStream_Click(eventInfo) {
    	var st = Windows.Storage;
    	var writeStream, writer, randomStreamOut;
    	st.ApplicationData.current.localFolder.createFileAsync("file.txt", st.CreationCollisionOption.replaceExisting)
				.then(function (file) {
					return file.openAsync(st.FileAccessMode.readWrite)
				})
				.then(function (randomStream) {
					randomStreamOut = randomStream;
					writeStream = randomStream.getOutputStreamAt(0);
					writer = new st.Streams.DataWriter(writeStream);
					writer.writeString(new Date().toString());
					var buffer = writer.detachBuffer();
					return writeStream.writeAsync(buffer)
				})
				.then(function(length){
					writer.close();
					writeStream.close();
					randomStreamOut.close();
				})
    }

    function ReadFileThroughFileIO_Click(eventInfo) {
    	var st = Windows.Storage;
    	st.ApplicationData.current.localFolder.getFileAsync("file.txt")
				.then(function (file) {
					st.FileIO.readLinesAsync(file).then(function(lines){
						var x = lines;
					});
				});
    }

    function ReadFileThroughStream_Click(eventInfo) {
    	var st = Windows.Storage;
    	var randomStreamOut, readerStream, reader;
    	st.ApplicationData.current.localFolder.getFileAsync("file.txt")
				.then(function (file) {
					return file.openAsync(st.FileAccessMode.readWrite)
				})
				.then(function (randomStream) {
					randomStreamOut = randomStream;
					readerStream = randomStream.getInputStreamAt(0);
					reader = new st.Streams.DataReader(readerStream);
					reader.loadAsync(randomStream.size);
				})
				.then(function (fileLength) {
					var content = reader.readString(fileLength);
					reader.close();
					readerStream.close();
					randomStreamOut.close();
				});
    }

    function DeleteFile_Click(eventInfo) {
    	Windows.Storage.ApplicationData.current.localFolder.getFileAsync("file.txt").then(function (file) {
				file.deleteAsync();
			});
    }

    function CreateFolder_Click(eventInfo) {
    	Windows.Storage.ApplicationData.current.localFolder.createFolderAsync("folder");
    }

    function DeleteFolder_Click(eventInfo) {
    	Windows.Storage.ApplicationData.current.localFolder.getFolderAsync("folder")
				.then(function (folder) {
					folder.deleteAsync();
				});
    }

    function UseFileOpenPicker_Click(eventInfo) {
    	var pk = Windows.Storage.Pickers;
    	var filePicker = new pk.FileOpenPicker();
    	filePicker.fileTypeFilter.append(".txt");
    	filePicker.viewMode = pk.PickerViewMode.thumbnail;
    	filePicker.pickSingleFileAsync()
				.then(function (file) {
					if (file != null){
						Windows.Storage.FileIO.readBufferAsync(file)
							.then(function(buffer){
								var dataReader = Windows.Storage.Streams.DataReader.fromBuffer(buffer);
								var fileContent = dataReader.readString(buffer.length);
							});
					}
				});
    }

    function UseFileSavePicker_Click(eventInfo) {
    	var filePicker = new Windows.Storage.Pickers.FileSavePicker();
    	filePicker.fileTypeChoices.insert("Plain Text", [".txt"]);
    	filePicker.pickSaveFileAsync()
				.then(function (file) {
					if (file != null) {
						Windows.Storage.FileIO.writeTextAsync(new Date().toString());
					}
				});
    }

    function UseFolderSavePicker_Click(eventInfo) {
    	var folderPicker = new Windows.Storage.Pickers.FolderPicker();
    	folderPicker.fileTypeFilter.append(".txt");
    	folderPicker.pickSingleFolderAsync()
				.then(function (folder) {
					var x = folder;
				});
    }

    app.start();
})();