﻿// For an introduction to the Page Control template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232511
(function () {
    "use strict";

    WinJS.UI.Pages.define("/pages/capture/capture.html", {
        mediaCapture: null,
        isRecording: false,
        // This function is called whenever a user navigates to this page. It
        // populates the page elements with the app's data.
        ready: function (element, options) {

            var enu = Windows.Devices.Enumeration;
            var capture = Windows.Media.Capture;
            var self = this;

            // Ottengo la lista delle periferiche video e audio
            var videoDevices = enu.DeviceInformation.findAllAsync(enu.DeviceClass.videoCapture);
            var audioDevices = enu.DeviceInformation.findAllAsync(enu.DeviceClass.audioCapture);

            // Aspetto di avere entrambe le liste
            WinJS.Promise.join([videoDevices, audioDevices]).then(function (devices) {

                // Creo l'oggetto per la gestione delle periferiche
                self.mediaCapture = new capture.MediaCapture();
                //self.mediaCapture.Failed += mediaCapture_Failed;
                //self.mediaCapture.RecordLimitationExceeded += mediaCapture_RecordLimitationExceeded;

                // Imposto gli id delle periferiche
                var s = new capture.MediaCaptureInitializationSettings();
                s.videoDeviceId = devices[0][0].id;
                s.audioDeviceId = devices[1][0].id;
                
                // Inizializzo le periferiche
                self.mediaCapture.initializeAsync(s).then(function () {
                    // Associo all'elemento per avere l'anteprima
                    video.src = URL.createObjectURL(self.mediaCapture, { oneTimeOnly: true });
                });
            });

            var prop = Windows.Media.MediaProperties;
            recordAudio.addEventListener("click", function () {
                self.record("file.mp3", prop.MediaEncodingProfile.createMp3(prop.AudioEncodingQuality.medium));
            });
            recordVideo.addEventListener("click", function () {
                self.record("file.mp4", prop.MediaEncodingProfile.createMp4(prop.VideoEncodingQuality.hd720p));
            });
            takePhoto.addEventListener("click", function () {
                self.takePhoto();
            });
            stopRecording.addEventListener("click", function () {
                self.isRecording = false;
                self.mediaCapture.stopRecordAsync();
            });
        },

        takePhoto: function () {
            var self = this;
            var stopPromise = WinJS.Promise.as(null);
            // Mi assicuro che non stia più registrando
            if (this.isRecording)
                stopPromise = this.mediaCapture.StopRecordAsync();

            var storage = Windows.Storage;
            var prop = Windows.Media.MediaProperties;
            // Encoding in JPEG
            var profile = prop.ImageEncodingProperties.createJpeg();

            // Creo il file su cui scrivere
            var filePromise = storage.ApplicationData.current.temporaryFolder.createFileAsync("photo.jpg",
                storage.CreationCollisionOption.replaceExisting);

            // Aspetto che abbia fermato la registrazione precedente
            // e aspetto che il file sia pronto per scrivere
            WinJS.Promise.join([stopPromise, filePromise]).then(function (r) {
                // Catturo l'immagine
                self.mediaCapture.capturePhotoToStorageFileAsync(profile, r[1]);
            });
        },

        record: function (name, profile) {
            var self = this;
            var stopPromise = WinJS.Promise.as(null);
            // Mi assicuro che non stia più registrando
            if (this.isRecording)
                stopPromise = this.mediaCapture.StopRecordAsync();

            var storage = Windows.Storage;
            // Creo il file su cui scrivere
            var filePromise = storage.ApplicationData.current.temporaryFolder.createFileAsync(name,
                storage.CreationCollisionOption.replaceExisting);
            
            // Aspetto che abbia fermato la registrazione precedente
            // e aspetto che il file sia pronto per scrivere
            WinJS.Promise.join([stopPromise, filePromise]).then(function (r) {
                self.isRecording = true;
                // Avvio la registrazione
                self.mediaCapture.startRecordToStorageFileAsync(profile, r[1]);
            });
        },
        unload: function () {
            if (this.isRecording) {
                this.capture.stopRecordAsync();
            }
            this.isRecording = false;
        },

        updateLayout: function (element, viewState, lastViewState) {
            /// <param name="element" domElement="true" />

            // TODO: Respond to changes in viewState.
        }
    });
})();
