﻿// For an introduction to the Page Control template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232511
(function () {
    "use strict";

    var bt = Windows.Networking.BackgroundTransfer;
    var st = Windows.Storage;

    WinJS.UI.Pages.define("/pages/backgroundTransfer/backgroundTransfer.html", {

        pendingPromises: [],

        // This function is called whenever a user navigates to this page. It
        // populates the page elements with the app's data.
        ready: function (element, options) {

            var self = this;

            // Recupero la lista dei downloads
            bt.BackgroundDownloader.getCurrentDownloadsAsync().then(function (operations) {
                operations.forEach(function (o) {
                    // Gestisco ogni operazione
                    self.handleOperation(o, false);
                });
            });

            start.addEventListener("click", this.start.bind(this));
            pause.addEventListener("click", this.pause.bind(this));
            stop.addEventListener("click", this.stop.bind(this));
        },

        unload: function () {
            // TODO: Respond to navigations away from this page.
        },

        start: function () {
            var self = this;

            // Creo il file dove depositare il download
            st.ApplicationData.current.temporaryFolder
                .createFileAsync("download.exe", st.CreationCollisionOption.generateUniqueName)
                .then(function (file) {
                    var downloader = bt.BackgroundDownloader();
                    // Definisco le policy di download
                    downloader.costPolicy = bt.BackgroundTransferCostPolicy.unrestrictedOnly;
                    // Eventuali Header custom
                    //downloader.setRequestHeader("Authorization", "OAuth ....");
                    //downloader.serverCredential

                    var uri = new Windows.Foundation.Uri("http://accord.googlecode.com/files/Accord.NET%20Framework-2.7.0.exe");
                    var operation = downloader.createDownload(uri, file);
                    self.handleOperation(operation, true);
                });
        },

        pause: function () {
            bt.BackgroundDownloader.getCurrentDownloadsAsync().then(function (operations) {
                operations.forEach(function (o) {
                    o.pause();
                });
            });
        },

        stop: function () {
            this.pendingPromises.forEach(function (p) {
                p.cancel();
            });
        },

        onProgress: function (operation) {
            /// <param name="operation" type="Windows.Networking.BackgroundTransfer.DownloadOperation" />
            switch (operation.progress.status) {
                case bt.BackgroundTransferStatus.canceled:
                    description.textContent = "cancellato";
                    break;
                case bt.BackgroundTransferStatus.completed:
                    description.textContent = "completato";
                    break;
                case bt.BackgroundTransferStatus.idle:
                    description.textContent = "in attesa";
                    break;
                case bt.BackgroundTransferStatus.pausedByApplication:
                    description.textContent = "pausa da applicazione";
                    break;
                case bt.BackgroundTransferStatus.pausedCostedNetwork:
                    description.textContent = "pausa per costo rete";
                    break;
                case bt.BackgroundTransferStatus.pausedNoNetwork:
                    description.textContent = "pausa nessuna rete";
                    break;
                case bt.BackgroundTransferStatus.running:
                    description.textContent = "in corso";
                    break;
            }

            if (operation.progress.totalBytesToReceive > 0) {
                // Calcolo la percentuale
                progress.textContent = (operation.progress.bytesReceived * 100 / operation.progress.totalBytesToReceive);
            }
        },

        removeOperationPromise: function (operation) {
            var i = this.pendingPromises.indexOf(operation);;
            if (i >= 0) {
                this.pendingPromises.splice(i, 1);
            }
        },

        handleOperation: function (operation, isNew) {
            var self = this;

            /// <param name="operation" type="Windows.Networking.BackgroundTransfer.DownloadOperation" />
            var operationPromise;

            // A seconda che l'operazione è nuova o meno
            // avvio il download o l'attach
            if (isNew) {
                operationPromise = operation.startAsync();
            } else {
                operationPromise = operation.attachAsync();
            }
            // Metto nella lista dei promise in corso
            this.pendingPromises.push(operationPromise);

            // Aggiorno subito
            this.onProgress(operation);

            operationPromise.then(function () {
                // Tolgo dalla lista dei promise in corso
                self.removeOperationPromise(operationPromise);

                // Apro il file
                Windows.System.Launcher.launchFileAsync(operation.resultFile);
            }, function (e) {
                // Tolgo dalla lista dei promise in corso
                self.removeOperationPromise(operation);

                // Mostro il messaggio di errore
                description.textContent = e.message;
            }, this.onProgress.bind(this));
        },

        updateLayout: function (element, viewState, lastViewState) {
            /// <param name="element" domElement="true" />

            // TODO: Respond to changes in viewState.
        }
    });
})();
